package com.fastbee.deviceInfo.service;

import java.util.List;
import com.fastbee.deviceInfo.domain.DeviceInformationMiaoqing;

/**
 * 苗情设备基础信息Service接口
 * 
 * @author kerwincui
 * @date 2024-11-18
 */
public interface IDeviceInformationMiaoqingService 
{
    /**
     * 查询苗情设备基础信息
     * 
     * @param id 苗情设备基础信息主键
     * @return 苗情设备基础信息
     */
    public DeviceInformationMiaoqing selectDeviceInformationMiaoqingById(String deviceEncoding);

    /**
     * 查询苗情设备基础信息列表
     * 
     * @param deviceInformationMiaoqing 苗情设备基础信息
     * @return 苗情设备基础信息集合
     */
    public List<DeviceInformationMiaoqing> selectDeviceInformationMiaoqingList(DeviceInformationMiaoqing deviceInformationMiaoqing);

    /**
     * 新增苗情设备基础信息
     * 
     * @param deviceInformationMiaoqing 苗情设备基础信息
     * @return 结果
     */
    public int insertDeviceInformationMiaoqing(DeviceInformationMiaoqing deviceInformationMiaoqing);

    /**
     * 修改苗情设备基础信息
     * 
     * @param deviceInformationMiaoqing 苗情设备基础信息
     * @return 结果
     */
    public int updateDeviceInformationMiaoqing(DeviceInformationMiaoqing deviceInformationMiaoqing);

    /**
     * 批量删除苗情设备基础信息
     * 
     * @param ids 需要删除的苗情设备基础信息主键集合
     * @return 结果
     */
    public int deleteDeviceInformationMiaoqingByIds(Long[] ids);

    /**
     * 删除苗情设备基础信息信息
     * 
     * @param id 苗情设备基础信息主键
     * @return 结果
     */
    public int deleteDeviceInformationMiaoqingById(Long id);
}
